@@ -26,7 +26,7 @@ sub prehook_sysopen {
 sub _install_open; # Provided by open.xs
 sub _install_sysopen; # Provided by open.xs
 
-our $VERSION = '0.30.0';
+our $VERSION = '0.31.0';
 XSLoader::load( 'overload::open', $VERSION );
 _install_open("OP_OPEN");
 _install_sysopen("OP_SYSOPEN");
@@ -41,7 +41,7 @@ overload::open - Hooks the native open function
 
 =head1 SYNOPSIS
 
-  use overload::open 'my_callback';
+  use overload::open;
   my %opened_files;
   sub my_callback { return if !@_; $opened_files{shift}++ }
   overload::open->prehook_open(\&my_callback);
@@ -56,7 +56,10 @@ It does this using XS and replacing the OP_OPEN/OP_SYSOPEN opcode's with an XS
 function. This function will call your provided sub, then once that returns
 it will run the original OP.
 
-This function I<should> work fine if you call C<open> or C<sysopen> inside the callback.
+=head1 FEATURES
+
+This function will work fine if you call C<open> or C<sysopen> inside the callback
+due to it detecting recursive calls and not calling the callback for recursive calls.
 
 You are not allowed to pass XS subs as the callback because then this could result
 in a recursive loop. If you need to do this, wrap the XS function in a native Perl
